(runners)=

# Runners for simulation software.

Support module for running CORSIKA and sim_telarray.

## corsika_runner

(corsika-runner-1)=

```{eval-rst}
.. automodule:: runners.corsika_runner
   :members:
```

## simtel_runner

(simtel-runner-1)=

```{eval-rst}
.. automodule:: runners.simtel_runner
   :members:
```

## corsika_simtel_runner

(corsika-simtel-runner-1)=

```{eval-rst}
.. automodule:: runners.corsika_simtel_runner
   :members:
```

## runner_services

(runner-services1)=

```{eval-rst}
.. automodule:: runners.runner_services
   :members:
```
